@@ -35,7 +35,7 @@ QTextDocument* Converter::convert( const QString &fileName )
     QTextFrame *rootFrame = textDocument->rootFrame();
     rootFrame->setFrameFormat( frameFormat );
 
-    emit addMetaData( Okular::DocumentInfo::MimeType, "text/plain" );
+    emit addMetaData( Okular::DocumentInfo::MimeType, QStringLiteral("text/plain") );
 
     return textDocument;
 }
